@@ -261,7 +261,7 @@ void button_press_callback(GtkWidget *widget, GdkEventButton *event,
 		if(event->state & GDK_CONTROL_MASK)
 			gtk_gs_scroll(GTK_GS(ggv->gs), -64, 0);
 		else if(event->state & GDK_SHIFT_MASK)
-			zoom_to(ggv, ggv_compute_spec(GTK_GS(ggv->gs)->zoom_factor)+1);
+			zoom_to(ggv, ggv_compute_spec(GTK_GS(ggv->gs)->zoom_factor) + 1);
 		else
 			gtk_gs_scroll(GTK_GS(ggv->gs), 0, -64);
 		break;
@@ -278,7 +278,7 @@ void button_press_callback(GtkWidget *widget, GdkEventButton *event,
         default:
                 break;
         }
-        gtk_clist_select_row (GTK_CLIST (ggv->pagelist),  GTK_GS(ggv->gs)->current_page,1);
+        gtk_clist_select_row (GTK_CLIST (ggv->pagelist), GTK_GS(ggv->gs)->current_page, 1);
 
 }
 
@@ -1094,6 +1094,8 @@ void prefs_apply_callback(GtkWidget *w, gint page, ggv_prefs *p)
                 (g_strdup(gtk_entry_get_text (GTK_ENTRY (p->unzip))));
         gtk_gs_defaults_set_unbzip2_cmd
                 (g_strdup(gtk_entry_get_text (GTK_ENTRY (p->unbzip2))));
+        gtk_gs_defaults_set_alpha_parameters
+                (g_strdup(gtk_entry_get_text(GTK_ENTRY(p->alpha_params))));
 
         if(ggv_print_cmd)
                 g_free(ggv_print_cmd);
