@@ -170,7 +170,7 @@ struct _ggv_window {
 struct _ggv_prefs
 {
         GnomePropertyBox *pbox;
-        GtkWidget *gs, *scan_pdf, *unzip, *unbzip2, *print;   /* entries */
+        GtkWidget *gs, *alpha_params, *scan_pdf, *unzip, *unbzip2, *print;   /* entries */
         GtkWidget *size, *zoom, *orientation, *units;         /* option menus */
         GtkWidget *watch, *aa, *override_size, *respect_eof, *show_scroll_rect; /* checkbuttons */
         GtkWidget *override_orientation;
