@@ -1005,11 +1005,12 @@ start_interpreter (GtkGS *gs)
 	int std_out[2]; /* pipe from interp stdout */
 	int std_err[2]; /* pipe from interp stderr */
 
-#define NUM_ARGS    100
-#define NUM_GS_ARGS (NUM_ARGS - 10)
+#define NUM_ARGS       100
+#define NUM_GS_ARGS    (NUM_ARGS - 20)
+#define NUM_ALPHA_ARGS 10
 
         char *argv[NUM_ARGS], *dir, *gv_env;
-        char **gs_args;
+        char **gs_args, **alpha_args = NULL;
         int argc = 0, i;
 
 	if (!gs->gs_filename)
@@ -1026,8 +1027,16 @@ start_interpreter (GtkGS *gs)
         for(i = 0; i < NUM_GS_ARGS && gs_args[i]; i++, argc++)
                 argv[argc] = gs_args[i];
 
-        if(gs->antialiased ) 
-		argv[argc++] = "-sDEVICE=x11alpha";
+        if(gs->antialiased ) {
+                if(strlen(gtk_gs_defaults_get_alpha_parameters()) == 0)
+                        alpha_args = g_strsplit(ALPHA_PARAMS, " ",
+                                                NUM_ALPHA_ARGS);
+                else
+                        alpha_args = g_strsplit(gtk_gs_defaults_get_alpha_parameters(),
+                                                " ", NUM_ALPHA_ARGS);
+                for(i = 0; i < NUM_ALPHA_ARGS && alpha_args[i]; i++, argc++)
+                        argv[argc] = alpha_args[i];
+        }
         else 
 		argv[argc++] = "-sDEVICE=x11";
         argv[argc++] = "-dNOPAUSE";
@@ -1111,6 +1120,8 @@ start_interpreter (GtkGS *gs)
                 /* Notify error */
                 g_print("Unable to execute [%s]\n", argv[0]);
                 g_strfreev(gs_args);
+                if(alpha_args)
+                        g_strfreev(alpha_args);
                 g_free(gv_env);
 		_exit(1);
 		break;
@@ -1498,19 +1509,32 @@ gtk_gs_center_page(GtkGS *gs)
 void
 gtk_gs_scroll(GtkGS *gs, gint x_delta, gint y_delta)
 {
-        gfloat hval, vval;
+        gfloat hval, vval, uhval, lhval, uvval, lvval;
 
         g_return_if_fail(gs != NULL);
         g_return_if_fail(GTK_IS_GS(gs));
 
         hval = gs->hadj->value + ((gfloat)x_delta)/gs->width;
         vval = gs->vadj->value + ((gfloat)y_delta)/gs->height;
-        if(hval <= gs->hadj->upper - gs->hadj->page_size/2 &&
-           hval >= gs->hadj->lower + gs->hadj->page_size/2)
-                gtk_adjustment_set_value(gs->hadj, hval);
-        if(vval <= gs->vadj->upper - gs->vadj->page_size/2 &&
-           vval >= gs->vadj->lower + gs->vadj->page_size/2)
-                gtk_adjustment_set_value(gs->vadj, vval);
+        uhval = gs->hadj->upper - gs->hadj->page_size/2;
+        lhval = gs->hadj->lower + gs->hadj->page_size/2;
+        uvval = gs->vadj->upper - gs->vadj->page_size/2;
+        lvval = gs->vadj->lower + gs->vadj->page_size/2;
+        if(hval <= uhval) {
+                if(hval >= lhval)
+                        gtk_adjustment_set_value(gs->hadj, hval);
+                else
+                        gtk_adjustment_set_value(gs->hadj, lhval);
+        } else
+                gtk_adjustment_set_value(gs->hadj, uhval);
+
+        if(vval <= uvval) {
+                if(vval >= lvval)
+                        gtk_adjustment_set_value(gs->vadj, vval);
+                else
+                        gtk_adjustment_set_value(gs->vadj, lvval);
+        } else
+                gtk_adjustment_set_value(gs->vadj, uvval);
 }
 
 void
